# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class RadioGroup(Component):
    """A RadioGroup component.
RadioGroup

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    Unique ID to identify this component in Dash callbacks.

- button_style (a value equal to: 'outline', 'solid'; optional):
    The style type of radio button.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- disabled (boolean; optional):
    Disable all radio buttons.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- option_type (a value equal to: 'default', 'button'; optional):
    Set Radio optionType.

- options (list of strings | list of numbers; optional):
    Set children optional.

- size (a value equal to: 'large', 'middle', 'small'; optional):
    The size of radio button.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- value (string | number; optional):
    Used for setting the currently selected value."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_antd'
    _type = 'RadioGroup'
    @_explicitize_args
    def __init__(self, children=None, button_style=Component.UNDEFINED, disabled=Component.UNDEFINED, options=Component.UNDEFINED, option_type=Component.UNDEFINED, size=Component.UNDEFINED, value=Component.UNDEFINED, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'button_style', 'class_name', 'disabled', 'key', 'option_type', 'options', 'size', 'style', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'button_style', 'class_name', 'disabled', 'key', 'option_type', 'options', 'size', 'style', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(RadioGroup, self).__init__(children=children, **args)



from typing import Optional

import dash

import dash_antd as ant

_ROOT_STYLE = {
    "overflow": "auto",
    "height": "100vh",
    "position": "fixed",
    "left": 0,
    "top": 0,
    "bottom": 0,
    "borderInlineEnd": "1px solid rgba(253, 253, 253, 0.12)",
    "overflowX": "hidden",
}


def get_nav_item(page):
    if "icon" in page:
        return {"label": page["title"], "key": page["path"], "path": page["path"], "icon": page["icon"]}
    return {"label": page["title"], "key": page["path"], "path": page["path"]}


def generate_sidebar_layout(primary_color: Optional[str] = None, use_dark_theme: bool = False) -> ant.ConfigProvider:
    nav_items = [get_nav_item(page) for page in dash.page_registry.values()]

    token = {}
    if primary_color is not None:
        token["colorPrimary"] = primary_color

    return ant.ConfigProvider(
        id="app-config",
        use_dark_theme=use_dark_theme,
        token=token,
        children=ant.Layout(
            has_sidebar=True,
            children=[
                ant.Sidebar(
                    style=_ROOT_STYLE,
                    theme="light",
                    children=[
                        ant.Menu(id="page-nav", items=nav_items, selected_keys=["page-1"], style={"marginRight": -2}),
                        ant.Divider("Controls"),
                    ],
                ),
                ant.Layout(
                    style={"marginLeft": 200, "minHeight": "100vh"},
                    children=[
                        ant.Content(
                            dash.page_container,
                            id="page-content",
                            style={"margin": "0", "padding": 0},
                        ),
                    ],
                ),
            ],
        ),
    )



from __future__ import annotations

from dataclasses import dataclass, fields
from typing import Any


def parse_tokens(raw: dict[str, Any]) -> Colors:
    field_names = {field.name for field in fields(Colors)}
    converted = {key.replace("-", "_"): value for key, value in raw.items() if not key.startswith("_")}
    return Colors(**{k: v for k, v in converted.items() if k in field_names})


@dataclass(frozen=True)
class Model:
    fontFamily: str
    fontSize: int
    lineWidth: int
    lineType: str
    motionUnit: float
    motionBase: int
    motionEaseOutCirc: str
    motionEaseInOutCirc: str
    motionEaseOut: str
    motionEaseInOut: str
    motionEaseOutBack: str
    motionEaseInBack: str
    motionEaseInQuint: str
    motionEaseOutQuint: str
    borderRadius: int
    sizeUnit: int
    sizeStep: int
    sizePopupArrow: int
    controlHeight: int
    zIndexBase: int
    zIndexPopupBase: int
    opacityImage: int
    wireframe: bool

    sizeXXL: int
    sizeXL: int
    sizeLG: int
    sizeMD: int
    sizeMS: int
    size: int
    sizeSM: int
    sizeXS: int
    sizeXXS: int
    controlHeightSM: int
    controlHeightXS: int
    controlHeightLG: int
    motionDurationFast: str
    motionDurationMid: str
    motionDurationSlow: str
    fontSizes: list[int]
    lineHeights: list[float]
    lineWidthBold: int
    borderRadiusXS: int
    borderRadiusSM: int
    borderRadiusLG: int
    borderRadiusOuter: int

    fontSizeSM: int
    fontSizeLG: int
    fontSizeXL: int
    fontSizeHeading1: int
    fontSizeHeading2: int
    fontSizeHeading3: int
    fontSizeHeading4: int
    fontSizeHeading5: int
    fontSizeIcon: int
    lineHeight: float
    lineHeightLG: float
    lineHeightSM: float
    lineHeightHeading1: float
    lineHeightHeading2: float
    lineHeightHeading3: float
    lineHeightHeading4: float
    lineHeightHeading5: float
    controlOutlineWidth: int
    controlInteractiveSize: int
    controlItemBgHover: str
    controlItemBgActive: str
    controlItemBgActiveHover: str
    controlItemBgActiveDisabled: str
    controlTmpOutline: str
    controlOutline: str
    fontWeightStrong: int
    opacityLoading: float
    linkDecoration: str
    linkHoverDecoration: str
    linkFocusDecoration: str
    controlPaddingHorizontal: int
    controlPaddingHorizontalSM: int
    paddingXXS: int
    paddingXS: int
    paddingSM: int
    padding: int
    paddingMD: int
    paddingLG: int
    paddingXL: int
    paddingContentHorizontalLG: int
    paddingContentVerticalLG: int
    paddingContentHorizontal: int
    paddingContentVertical: int
    paddingContentHorizontalSM: int
    paddingContentVerticalSM: int
    marginXXS: int
    marginXS: int
    marginSM: int
    margin: int
    marginMD: int
    marginLG: int
    marginXL: int
    marginXXL: int
    boxShadow: str
    boxShadowSecondary: str
    screenXS: int
    screenXSMin: int
    screenXSMax: int
    screenSM: int
    screenSMMin: int
    screenSMMax: int
    screenMD: int
    screenMDMin: int
    screenMDMax: int
    screenLG: int
    screenLGMin: int
    screenLGMax: int
    screenXL: int
    screenXLMin: int
    screenXLMax: int
    screenXXL: int
    screenXXLMin: int
    screenXXLMax: int
    boxShadowPopoverArrow: str
    boxShadowCard: str
    boxShadowDrawerRight: str
    boxShadowDrawerLeft: str
    boxShadowDrawerUp: str
    boxShadowDrawerDown: str
    boxShadowTabsOverflowLeft: str
    boxShadowTabsOverflowRight: str
    boxShadowTabsOverflowTop: str
    boxShadowTabsOverflowBottom: str


@dataclass(frozen=True)
class Colors:
    blue: str
    purple: str
    cyan: str
    green: str
    magenta: str
    pink: str
    red: str
    orange: str
    yellow: str
    volcano: str
    geekblue: str
    gold: str
    lime: str
    colorPrimary: str
    colorSuccess: str
    colorWarning: str
    colorError: str
    colorInfo: str
    colorTextBase: str
    colorBgBase: str
    blue_1: str
    blue_2: str
    blue_3: str
    blue_4: str
    blue_5: str
    blue_6: str
    blue_7: str
    blue_8: str
    blue_9: str
    blue_10: str
    purple_1: str
    purple_2: str
    purple_3: str
    purple_4: str
    purple_5: str
    purple_6: str
    purple_7: str
    purple_8: str
    purple_9: str
    purple_10: str
    cyan_1: str
    cyan_2: str
    cyan_3: str
    cyan_4: str
    cyan_5: str
    cyan_6: str
    cyan_7: str
    cyan_8: str
    cyan_9: str
    cyan_10: str
    green_1: str
    green_2: str
    green_3: str
    green_4: str
    green_5: str
    green_6: str
    green_7: str
    green_8: str
    green_9: str
    green_10: str
    magenta_1: str
    magenta_2: str
    magenta_3: str
    magenta_4: str
    magenta_5: str
    magenta_6: str
    magenta_7: str
    magenta_8: str
    magenta_9: str
    magenta_10: str
    pink_1: str
    pink_2: str
    pink_3: str
    pink_4: str
    pink_5: str
    pink_6: str
    pink_7: str
    pink_8: str
    pink_9: str
    pink_10: str
    red_1: str
    red_2: str
    red_3: str
    red_4: str
    red_5: str
    red_6: str
    red_7: str
    red_8: str
    red_9: str
    red_10: str
    orange_1: str
    orange_2: str
    orange_3: str
    orange_4: str
    orange_5: str
    orange_6: str
    orange_7: str
    orange_8: str
    orange_9: str
    orange_10: str
    yellow_1: str
    yellow_2: str
    yellow_3: str
    yellow_4: str
    yellow_5: str
    yellow_6: str
    yellow_7: str
    yellow_8: str
    yellow_9: str
    yellow_10: str
    volcano_1: str
    volcano_2: str
    volcano_3: str
    volcano_4: str
    volcano_5: str
    volcano_6: str
    volcano_7: str
    volcano_8: str
    volcano_9: str
    volcano_10: str
    geekblue_1: str
    geekblue_2: str
    geekblue_3: str
    geekblue_4: str
    geekblue_5: str
    geekblue_6: str
    geekblue_7: str
    geekblue_8: str
    geekblue_9: str
    geekblue_10: str
    gold_1: str
    gold_2: str
    gold_3: str
    gold_4: str
    gold_5: str
    gold_6: str
    gold_7: str
    gold_8: str
    gold_9: str
    gold_10: str
    lime_1: str
    lime_2: str
    lime_3: str
    lime_4: str
    lime_5: str
    lime_6: str
    lime_7: str
    lime_8: str
    lime_9: str
    lime_10: str
    colorText: str
    colorTextSecondary: str
    colorTextTertiary: str
    colorTextQuaternary: str
    colorFill: str
    colorFillSecondary: str
    colorFillTertiary: str
    colorFillQuaternary: str
    colorBgLayout: str
    colorBgContainer: str
    colorBgElevated: str
    colorBgSpotlight: str
    colorBorder: str
    colorBorderSecondary: str
    colorPrimaryBg: str
    colorPrimaryBgHover: str
    colorPrimaryBorder: str
    colorPrimaryBorderHover: str
    colorPrimaryHover: str
    colorPrimaryActive: str
    colorPrimaryTextHover: str
    colorPrimaryText: str
    colorPrimaryTextActive: str
    colorSuccessBg: str
    colorSuccessBgHover: str
    colorSuccessBorder: str
    colorSuccessBorderHover: str
    colorSuccessHover: str
    colorSuccessActive: str
    colorSuccessTextHover: str
    colorSuccessText: str
    colorSuccessTextActive: str
    colorErrorBg: str
    colorErrorBgHover: str
    colorErrorBorder: str
    colorErrorBorderHover: str
    colorErrorHover: str
    colorErrorActive: str
    colorErrorTextHover: str
    colorErrorText: str
    colorErrorTextActive: str
    colorWarningBg: str
    colorWarningBgHover: str
    colorWarningBorder: str
    colorWarningBorderHover: str
    colorWarningHover: str
    colorWarningActive: str
    colorWarningTextHover: str
    colorWarningText: str
    colorWarningTextActive: str
    colorInfoBg: str
    colorInfoBgHover: str
    colorInfoBorder: str
    colorInfoBorderHover: str
    colorInfoHover: str
    colorInfoActive: str
    colorInfoTextHover: str
    colorInfoText: str
    colorInfoTextActive: str
    colorBgMask: str
    colorWhite: str
    colorLink: str
    colorLinkHover: str
    colorLinkActive: str
    colorFillContent: str
    colorFillContentHover: str
    colorFillAlter: str
    colorBgContainerDisabled: str
    colorBorderBg: str
    colorSplit: str
    colorTextPlaceholder: str
    colorTextDisabled: str
    colorTextHeading: str
    colorTextLabel: str
    colorTextDescription: str
    colorTextLightSolid: str
    colorHighlight: str
    colorBgTextHover: str
    colorBgTextActive: str
    colorIcon: str
    colorIconHover: str
    colorErrorOutline: str
    colorWarningOutline: str



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Input(Component):
    """An Input component.
A basic widget for getting the user input is a text field.
Keyboard and mouse can be used for providing or changing data.

Keyword arguments:

- id (string; optional):
    Unique ID to identify this component in Dash callbacks.

- addon_after (a list of or a singular dash component, string or number; optional):
    The label text displayed after (on the right side of) the input
    field.

- addon_before (a list of or a singular dash component, string or number; optional):
    The label text displayed before (on the left side of) the input
    field.

- allow_clear (boolean; optional):
    If allow to remove input content with clear icon.

- autocomplete (a value equal to: 'on', 'off'; optional):
    This attribute indicates whether the value of the control can be
    automatically completed by the browser.

- bordered (boolean; optional):
    Whether has border style.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- debounce (boolean; default False):
    If True, changes to input will be sent back to the Dash server
    only when the enter key is pressed or when the component loses
    focus.  If it's False, it will sent the value back on every
    change.

- disabled (boolean; optional):
    Whether the input is disabled.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; required):
        Holds the name of the component that is loading.

    - is_loading (boolean; required):
        Determines if the component is loading or not.

    - prop_name (string; required):
        Holds which property is loading.

- max (string | number; optional):
    The maximum (numeric or date-time) value for this item, which must
    not be less than its minimum (min attribute) value.

- max_length (number; optional):
    The max length.

- min (string | number; optional):
    The minimum (numeric or date-time) value for this item, which must
    not be greater than its maximum (max attribute) value.

- n_blur (number; default 0):
    Number of times the input lost focus.

- n_blur_timestamp (number; default -1):
    Last time the input lost focus.

- n_submit (number; default 0):
    Number of times the `Enter` key was pressed while the input had
    focus.

- n_submit_timestamp (number; default -1):
    Last time that `Enter` was pressed.

- placeholder (string; optional):
    A hint to the user of what can be entered in the control.

- readonly (boolean; optional):
    Indicates whether the element can be edited.

- show_count (boolean; optional):
    Whether show character count.

- size (a value equal to: 'large', 'middle', 'small'; optional):
    The size of the input box.

- status (a value equal to: 'error', 'warning'; optional):
    Set validation status.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- type (a value equal to: 'number', 'text', 'password', 'email', 'range', 'search', 'tel', 'url', 'hidden'; optional):
    The type of control to render.

- value (string | number; optional):
    The input content value."""
    _children_props = ['addon_after', 'addon_before']
    _base_nodes = ['addon_after', 'addon_before', 'children']
    _namespace = 'dash_antd'
    _type = 'Input'
    @_explicitize_args
    def __init__(self, value=Component.UNDEFINED, addon_after=Component.UNDEFINED, addon_before=Component.UNDEFINED, allow_clear=Component.UNDEFINED, autocomplete=Component.UNDEFINED, bordered=Component.UNDEFINED, disabled=Component.UNDEFINED, max=Component.UNDEFINED, min=Component.UNDEFINED, max_length=Component.UNDEFINED, readonly=Component.UNDEFINED, show_count=Component.UNDEFINED, size=Component.UNDEFINED, n_blur=Component.UNDEFINED, n_blur_timestamp=Component.UNDEFINED, n_submit=Component.UNDEFINED, n_submit_timestamp=Component.UNDEFINED, debounce=Component.UNDEFINED, type=Component.UNDEFINED, status=Component.UNDEFINED, placeholder=Component.UNDEFINED, loading_state=Component.UNDEFINED, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'addon_after', 'addon_before', 'allow_clear', 'autocomplete', 'bordered', 'class_name', 'debounce', 'disabled', 'key', 'loading_state', 'max', 'max_length', 'min', 'n_blur', 'n_blur_timestamp', 'n_submit', 'n_submit_timestamp', 'placeholder', 'readonly', 'show_count', 'size', 'status', 'style', 'type', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'addon_after', 'addon_before', 'allow_clear', 'autocomplete', 'bordered', 'class_name', 'debounce', 'disabled', 'key', 'loading_state', 'max', 'max_length', 'min', 'n_blur', 'n_blur_timestamp', 'n_submit', 'n_submit_timestamp', 'placeholder', 'readonly', 'show_count', 'size', 'status', 'style', 'type', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(Input, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class TextArea(Component):
    """A TextArea component.
TextArea component.

Keyword arguments:

- id (string; optional):
    Unique ID to identify this component in Dash callbacks.

- allow_clear (boolean; optional):
    If allow to remove input content with clear icon.

- bordered (boolean; optional):
    Whether has border style.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- cols (number; optional):
    Defines the number of columns in a textarea.

- debounce (boolean; default False):
    If True, changes to input will be sent back to the Dash server
    only on enter or when losing focus. If it's False, it will sent
    the value back on every change.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; required):
        Holds the name of the component that is loading.

    - is_loading (boolean; required):
        Determines if the component is loading or not.

    - prop_name (string; required):
        Holds which property is loading.

- max_length (number; optional):
    The max length.

- n_blur (number; default 0):
    Number of times the input lost focus.

- n_blur_timestamp (number; default -1):
    Last time the input lost focus.

- n_clicks (number; default 0):
    An integer that represents the number of times that this element
    has been clicked on.

- n_submit (number; default 0):
    Number of times the `Enter` key was pressed while the textarea had
    focus.

- n_submit_timestamp (number; default -1):
    Last time that `Enter` was pressed.

- placeholder (string; optional):
    A hint to the user of what can be entered in the control.

- readonly (boolean; optional):
    Indicates whether the element can be edited.

- rows (number; optional):
    Defines the number of rows in a text area.

- show_count (boolean; optional):
    Whether show text count.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- value (string; default ''):
    The input content value."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_antd'
    _type = 'TextArea'
    @_explicitize_args
    def __init__(self, value=Component.UNDEFINED, allow_clear=Component.UNDEFINED, bordered=Component.UNDEFINED, cols=Component.UNDEFINED, max_length=Component.UNDEFINED, show_count=Component.UNDEFINED, readonly=Component.UNDEFINED, rows=Component.UNDEFINED, placeholder=Component.UNDEFINED, loading_state=Component.UNDEFINED, n_blur=Component.UNDEFINED, n_blur_timestamp=Component.UNDEFINED, n_submit=Component.UNDEFINED, n_submit_timestamp=Component.UNDEFINED, n_clicks=Component.UNDEFINED, debounce=Component.UNDEFINED, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'allow_clear', 'bordered', 'class_name', 'cols', 'debounce', 'key', 'loading_state', 'max_length', 'n_blur', 'n_blur_timestamp', 'n_clicks', 'n_submit', 'n_submit_timestamp', 'placeholder', 'readonly', 'rows', 'show_count', 'style', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'allow_clear', 'bordered', 'class_name', 'cols', 'debounce', 'key', 'loading_state', 'max_length', 'n_blur', 'n_blur_timestamp', 'n_clicks', 'n_submit', 'n_submit_timestamp', 'placeholder', 'readonly', 'rows', 'show_count', 'style', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(TextArea, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class DropdownMenu(Component):
    """A DropdownMenu component.
A Dropdown component

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    Unique ID to identify this component in Dash callbacks.

- arrow (boolean; optional):
    Whether the dropdown arrow should be visible.

- disabled (boolean; optional):
    Whether the dropdown menu is disabled.

- items (list of boolean | number | string | dict | lists; required):
    Items displayed in the dropdown menu.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- placement (a value equal to: 'bottom', 'bottomLeft', 'bottomRight', 'top', 'topLeft', 'topRight'; optional):
    Placement of popup menu.

- trigger (list of a value equal to: 'click', 'hover', 'contextMenu's; optional):
    The trigger mode which executes the dropdown action. Note that
    hover can't be used on touchscreens.

- visible (boolean; optional):
    Whether the dropdown menu is currently visible."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_antd'
    _type = 'DropdownMenu'
    @_explicitize_args
    def __init__(self, children=None, items=Component.REQUIRED, arrow=Component.UNDEFINED, disabled=Component.UNDEFINED, placement=Component.UNDEFINED, trigger=Component.UNDEFINED, visible=Component.UNDEFINED, id=Component.UNDEFINED, key=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'arrow', 'disabled', 'items', 'key', 'placement', 'trigger', 'visible']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'arrow', 'disabled', 'items', 'key', 'placement', 'trigger', 'visible']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['items']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(DropdownMenu, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Button(Component):
    """A Button component.
A basic Button component

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    Unique ID to identify this component in Dash callbacks.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- danger (boolean; default False):
    Set the danger status of button.

- disabled (boolean; default False):
    Disabled state of button.

- href (string; optional):
    Pass a URL (relative or absolute) to make the menu entry a link.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; required):
        Holds the name of the component that is loading.

    - is_loading (boolean; required):
        Determines if the component is loading or not.

    - prop_name (string; required):
        Holds which property is loading.

- n_clicks (number; default 0):
    An integer that represents the number of times that this element
    has been clicked on.

- shape (a value equal to: 'default', 'circle', 'round'; default 'default'):
    The shape of the button.

- size (a value equal to: 'large', 'middle', 'small'; default 'middle'):
    The size of the button.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- target (string; optional):
    Same as target attribute of a, works when href is specified.

- type (a value equal to: 'default', 'primary', 'ghost', 'dashed', 'link', 'text'; default 'default'):
    The type of the button."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_antd'
    _type = 'Button'
    @_explicitize_args
    def __init__(self, children=None, danger=Component.UNDEFINED, disabled=Component.UNDEFINED, shape=Component.UNDEFINED, size=Component.UNDEFINED, target=Component.UNDEFINED, type=Component.UNDEFINED, n_clicks=Component.UNDEFINED, loading_state=Component.UNDEFINED, href=Component.UNDEFINED, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'class_name', 'danger', 'disabled', 'href', 'key', 'loading_state', 'n_clicks', 'shape', 'size', 'style', 'target', 'type']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'class_name', 'danger', 'disabled', 'href', 'key', 'loading_state', 'n_clicks', 'shape', 'size', 'style', 'target', 'type']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Button, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Switch(Component):
    """A Switch component.
Switching Selector.

Keyword arguments:

- id (string; optional):
    Unique ID to identify this component in Dash callbacks.

- checked (boolean; optional):
    Specifies whether the radio is selected.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- disabled (boolean; optional):
    Disable radio.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; required):
        Holds the name of the component that is loading.

    - is_loading (boolean; required):
        Determines if the component is loading or not.

    - prop_name (string; required):
        Holds which property is loading.

- size (a value equal to: 'small', 'default'; optional):
    The size of the Switch.

- style (dict; optional):
    Defines CSS styles which will override styles previously set."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_antd'
    _type = 'Switch'
    @_explicitize_args
    def __init__(self, checked=Component.UNDEFINED, disabled=Component.UNDEFINED, size=Component.UNDEFINED, loading_state=Component.UNDEFINED, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'checked', 'class_name', 'disabled', 'key', 'loading_state', 'size', 'style']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'checked', 'class_name', 'disabled', 'key', 'loading_state', 'size', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(Switch, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Space(Component):
    """A Space component.
Set components spacing.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    Unique ID to identify this component in Dash callbacks.

- align (a value equal to: 'start', 'end', 'center', 'baseline'; optional):
    Align items.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- direction (a value equal to: 'vertical', 'horizontal'; optional):
    The space direction.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- size (number; optional):
    The space size.

- split (a list of or a singular dash component, string or number; optional):
    Set split.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- wrap (boolean; optional):
    Auto wrap line, when horizontal effective."""
    _children_props = ['split']
    _base_nodes = ['split', 'children']
    _namespace = 'dash_antd'
    _type = 'Space'
    @_explicitize_args
    def __init__(self, children=None, align=Component.UNDEFINED, direction=Component.UNDEFINED, size=Component.UNDEFINED, split=Component.UNDEFINED, wrap=Component.UNDEFINED, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'align', 'class_name', 'direction', 'key', 'size', 'split', 'style', 'wrap']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'align', 'class_name', 'direction', 'key', 'size', 'split', 'style', 'wrap']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Space, self).__init__(children=children, **args)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['dash_antd', 'dash_antd.ext']

package_data = \
{'': ['*']}

install_requires = \
['dash>=2.7,<3.0']

setup_kwargs = {
    'name': 'dash-antd',
    'version': '0.1.3',
    'description': 'Ant Design components for Plotly Dash',
    'long_description': '# Dash Ant Design Components\n\n<p align="center">\n<a href="https://github.com/roeap/dash-ant-design-components/actions"><img alt="Actions Status" src="https://github.com/roeap/dash-ant-design-components/actions/workflows/test.yaml/badge.svg"></a>\n<a href="https://codecov.io/gh/roeap/dash-ant-design-components">\n  <img src="https://codecov.io/gh/roeap/dash-ant-design-components/branch/main/graph/badge.svg?token=DNVIU3FXL5"/>\n</a>\n<a href="https://github.com/psf/black/blob/main/LICENSE"><img alt="License: MIT" src="https://black.readthedocs.io/en/stable/_static/license.svg"></a>\n<a href="https://pypi.org/project/dash-antd/"><img alt="PyPI" src="https://img.shields.io/pypi/v/dash-antd"></a>\n<a href="https://github.com/psf/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>\n</p>\n\nAnt Design components for Plotly Dash.\n\n## Install\n\nto install in your python environment.\n\n```shell\npoetry add dash-antd\n```\n\nor via pip.\n\n```shell\npip install dash-antd\n```\n\n## Development\n\nWe use [just](https://github.com/casey/just) as command runner, if you prefer not to install\njust, have a look at the `justfile` for detailed commands.\n\nTo manage python dependencies, we utilize [poetry](python-poetry.org/).\n\n### Getting Started\n\nInstall python and node dependencies.\n\n```sh\njust install\n```\n\nBuild the Dash packages.\n\n```sh\njust build\n```\n\nSee all commands with `just -l`\n\n### Example app\n\nAn example app is contained in the `example` folder. To run it execute:\n\n```sh\njust run\n```\n',
    'author': 'Robert Pack',
    'author_email': 'robstar.pack@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
